==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-update/translations/dde-update_en_US.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="en_US">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Preparing</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>View Logs</source>
        <translation>View Logs</translation>
    </message>
    <message>
        <source>Updates successful</source>
        <translation>Updates successful</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>Your computer will reboot soon %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Your computer will be turned off soon %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Hide Logs</source>
        <translation>Hide Logs</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>Update failed</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Unknown error</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Backup failed</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Insufficient disk space. Please clean up your disk and try again.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>Failed to connect to backup services. Please check and retry again.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>Failed to connect to update services. Please check and retry again.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Dependency error</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>DPKG error</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Back Up Again</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Abort</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Proceed to Update</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reboot</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Shut Down</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Preparing for updates…</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.38.1.tar.xz: BUILD/src/dde-update/translations/dde-update_en_US.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="en_US">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Preparing</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>Updates successful</source>
        <translation>Updates successful</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>Your computer will reboot soon %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Your computer will be turned off soon %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>View update logs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Export</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>Update failed</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Unknown error</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Backup failed</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Insufficient disk space. Please clean up your disk and try again.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>Failed to connect to backup services. Please check and retry again.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>Failed to connect to update services. Please check and retry again.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Dependency error</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>DPKG error</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Back Up Again</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Abort</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Proceed to Update</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reboot</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Shut Down</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Preparing for updates…</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>updatelog</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
